CREATE OR REPLACE PACKAGE plpdf_toolkit is
/**
 <config>
  <pck-name>PL/PDF Toolkit</pck-name>
  <pck-title>User's Guide</pck-title>
  <pck-version>v2.0.1</pck-version>
  <header-prc>plpdf_doc_xml.plpdf_header</header-prc>
  <header-size>15</header-size>
  <footer-prc>plpdf_doc_xml.plpdf_footer</footer-prc>
  <footer-size>10</footer-size>
 </config>
*/

/**
<h1>Introdution</h1>
<br/>
<p>
 PL/PDF Toolkit is a java library with PL/SQL interface for manipulating existing PDF documents.
</p>
<newpage/>
*/

/**
<h1>Certification</h1>
<h2>GetCertKey</h2>
<type>Function</type>
<desc>
  Generates preliminary certification key.
  This function should be run once when the PL/PDF package is installed. The function generates a string
  that should be sent to <a>mailto:info@plpdf.com</a>. Our representatives will send a certificate key back that should
  be used as the return value in the <i>pl_pdf_cert.SetCertKey</i> function.
</desc>
<params>-</params>
<return>
 <return-def>varchar2</return-def>
 <return-desc>Preliminary certificate key</return-desc>
</return>
<newpage/>
*/
function GetCertKey
  return varchar2;

/**
<h1>Types And Constants</h1>
<h2>t14font</h2>
<type>Subtype, VARHCAR2(30 CHAR)</type>
<desc>
 Standard Type 1 Fonts<br/>
 The PostScript names of 14 Type 1 fonts, known as the standard fonts.
 These fonts, or their font metrics and suitable substitution fonts, are required to be available to the viewer application.
</desc>
<br/>
*/
subtype t_14font is varchar2(30 char);

/**
<h2>t_color</h2>
<type>Record</type>
<desc>
Represents the RGB color triplet.
</desc>
<fields>
 <field>
  <field-def>r number</field-def>
  <field-desc>Value of the red component</field-desc>
 </field>
 <field>
  <field-def>g number</field-def>
  <field-desc>Value of the green component</field-desc>
 </field>
 <field>
  <field-def>b number</field-def>
  <field-desc>Value of the blue component</field-desc>
 </field>
</fields>
*/
type t_color is record (
  r number,
  g number,
  b number
  );
/**
<br/>
<h2>times-roman</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Times-Roman</constant-desc>
</constant>

<h2>times_bold</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Times-Bold</constant-desc>
</constant>

<h2>times_italic</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Times-Italic</constant-desc>
</constant>

<h2>times_bold_italic</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Times-BoldItalic</constant-desc>
</constant>

<h2>helvetica</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Helvetica</constant-desc>
</constant>

<h2>helvetica_bold</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Helvetica-Bold</constant-desc>
</constant>

<h2>helvetica_oblique</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Helvetica-Oblique</constant-desc>
</constant>

<h2>helvetica_bold_oblique</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Helvetica-BoldOblique</constant-desc>
</constant>

<h2>courier</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Courier</constant-desc>
</constant>

<h2>courier_bold</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Courier-Bold</constant-desc>
</constant>

<h2>courier_oblique</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Courier-Oblique</constant-desc>
</constant>

<h2>courier_bold_oblique</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Courier-BoldOblique</constant-desc>
</constant>

<h2>symbol</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>Symbol</constant-desc>
</constant>

<h2>zapf_dingbats</h2>
<type>Constant</type>
<constant>
 <constant-def>t_14font</constant-def>
 <constant-desc>ZapfDingbats</constant-desc>
</constant>
<newpage/>
*/
  times_roman constant t_14font := 'Times-Roman';
  times_bold constant t_14font := 'Times-Bold';
  times_italic constant t_14font := 'Times-Italic';
  times_bold_italic constant t_14font := 'Times-BoldItalic';
  helvetica constant t_14font := 'Helvetica';
  helvetica_bold constant t_14font := 'Helvetica-Bold';
  helvetica_oblique constant t_14font := 'Helvetica-Oblique';
  helvetica_bold_oblique constant t_14font := 'Helvetica-BoldOblique';
  courier constant t_14font := 'Courier';
  courier_bold constant t_14font := 'Courier-Bold';
  courier_oblique constant t_14font := 'Courier-Oblique';
  courier_bold_oblique constant t_14font := 'Courier-BoldOblique';
  symbol constant t_14font := 'Symbol';
  zapf_dingbats constant t_14font := 'ZapfDingbats';

/**
<br/>
<h2>Metadata</h2>
<type>Record</type>
<desc>
  A PDF document may include general information such as the documents title,
  author, and creation and modification dates. Such global information about the
  document itself (as opposed to its content or structure) is called metadata, and is
  intended to assist in cataloguing and searching for documents in external databases.
</desc>
<fields>
 <field>
  <field-def>Title</field-def>
  <field-desc>The documents title</field-desc>
 </field>
 <field>
  <field-def>Author</field-def>
  <field-desc>The name of the person who created the document</field-desc>
 </field>
 <field>
  <field-def>Subject</field-def>
  <field-desc>The subject of the document</field-desc>
 </field>
 <field>
  <field-def>Creator</field-def>
  <field-desc>If the document was converted to PDF from another format, the
   name of the application (for example, Adobe FrameMaker) that created the
   original document from which it was converted.
  </field-desc>
 </field>
 <field>
  <field-def>Keywords</field-def>
  <field-desc>Keywords associated with the document</field-desc>
 </field>
 <field>
  <field-def>Producer</field-def>
  <field-desc>If the document was converted to PDF from another format, the
   name of the application (for example, Acrobat Distiller) that converted it to PDF.
  </field-desc>
 </field>
 <field>
  <field-def>CreationDate</field-def>
  <field-desc>The date and time the document was created, in human-readable form</field-desc>
 </field>
 <field>
  <field-def>ModDate</field-def>
  <field-desc>The date and time the document was most recently modified, in human-readable form</field-desc>
 </field>
</fields>
*/
type t_metadata is record (
  Title varchar2(2000 char),
  Author varchar2(2000 char),
  Subject varchar2(2000 char),
  Creator varchar2(2000 char),
  Keywords varchar2(2000 char),
  Producer varchar2(2000 char),
  CreationDate date,
  ModDate date
  );

/**
<br/>
<h2>Merge input</h2>
<type>Record</type>
<desc>
  PDF document with some properties.
</desc>
<fields>
 <field>
  <field-def>inputfile</field-def>
  <field-desc>Source PDF file</field-desc>
 </field>
 <field>
  <field-def>password</field-def>
  <field-desc>The owner password of the PDF file (if encrypted).</field-desc>
 </field>
 <field>
  <field-def>overwrite_rect_x</field-def>
  <field-desc>Overwrite rectangle x coordinate</field-desc>
 </field>
 <field>
  <field-def>overwrite_rect_y</field-def>
  <field-desc>Overwrite rectangle y coordinate</field-desc>
 </field>
 <field>
  <field-def>overwrite_rect_w</field-def>
  <field-desc>Overwrite rectangle width</field-desc>
 </field>
 <field>
  <field-def>overwrite_rect_h</field-def>
  <field-desc>Overwrite rectangle heigth</field-desc>
 </field><field>
  <field-def>overwrite_rect_color</field-def>
  <field-desc>Overwrite rectangle fill color</field-desc>
 </field>
</fields>
*/
type t_merge_input is record (
  inputfile blob,
  password varchar2(255 char),
  overwrite_rect_x number,
  overwrite_rect_y number,
  overwrite_rect_w number,
  overwrite_rect_h number,
  overwrite_rect_color t_color
  );

/**
<br/>
<h2>Merge inputs</h2>
<type>Table</type>
<desc>
  Table of Merge input records.
</desc>
<records>
 <record>
  <record-def>Input record</field-def>
  <recordd-desc>PDF document with some properties</field-desc>
 </record>
</records>
*/
type t_merge_inputs is table of t_merge_input index by pls_integer;

/**
<newpage/>
<h1>Functions</h1>
<br/>
<h2>Encryption</h2>
<p>
  A PDF document can be encrypted to protect its contents from unauthorized
  access. Encryption applies to all strings and streams in the documents
  PDF file, but not to other object types such as integers and boolean values, which
  are used primarily to convey information about the documents structure rather
  than its content. Leaving these values unencrypted allows random access to the
  objects within a document, while encrypting the strings and streams protects the
  documents substantive contents.
</p>
*/

/**
<h2>Encrypt40</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 40 RC4 bit encryption.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document, including extracting text and graphics
    (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>The user is allowed to add or modify text annotations,
    fill in interactive form fields, and, if "modify" is also set, create or modify interactive form fields
    (including signature fields).
  </param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>The user is allowed to print the document.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function Encrypt40(
  p_inputfile blob,
  p_opassword varchar2,
  p_upassword varchar2 default null,
  p_canextractcontent boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false
  ) return blob;

/**
<h2>Encript128</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 128 RC4 bit encryption.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function Encrypt128(
  p_inputfile blob,
  p_opassword varchar2,
  p_upassword varchar2 default null,
  p_canassemble boolean default false,
  p_canextractcontent boolean default false,
  p_canextractforaccessibility boolean default false,
  p_canfillinform boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false,
  p_canmodifyprintresolution boolean default false
  ) return blob;

/**
<h2>AESEncript128</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 128 AES bit encryption.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function AESEncrypt128(
  p_inputfile blob,
  p_opassword varchar2,
  p_upassword varchar2 default null,
  p_canassemble boolean default false,
  p_canextractcontent boolean default false,
  p_canextractforaccessibility boolean default false,
  p_canfillinform boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false,
  p_canmodifyprintresolution boolean default false
  ) return blob;


/**
<h2>PublicKeyEncrypt40</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 40 RC4 bit encryption and public key certificate.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_certfile blob</param-def>
  <param-desc>the certificate file</param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document, including extracting text and graphics
    (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>The user is allowed to add or modify text annotations,
    fill in interactive form fields, and, if "modify" is also set, create or modify interactive form fields
    (including signature fields).
  </param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>The user is allowed to print the document.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function PublicKeyEncrypt40(
  p_inputfile blob,
  p_certfile blob,
  p_canextractcontent boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false
  ) return blob;

/**
<h2>PublicKeyEncript128</h2>
<type>Function</type>
<desc>
  Encrypt any PDF document using standard PDF 128 RC4 bit encryption and public key certificate.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_certfile blob</param-def>
  <param-desc>the certificate file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function PublicKeyEncrypt128(
  p_inputfile blob,
  p_certfile blob,
  p_canassemble boolean default false,
  p_canextractcontent boolean default false,
  p_canextractforaccessibility boolean default false,
  p_canfillinform boolean default false,
  p_canmodify boolean default false,
  p_canmodifyannotations boolean default false,
  p_canprint boolean default false,
  p_canmodifyprintresolution boolean default false
  ) return blob;

/**
<h2>Decrypt</h2>
<type>Function</type>
<desc>
  Decrypt an encrypted (40 or 128 bits) PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 </params>
<return>
  <return-def>blob</return-def>
  <return-desc>result PDF document</return-desc>
</return>
*/
function Decrypt(
  p_inputfile blob,
  p_password varchar2
  ) return blob;

/**
<h2>PublicKeyDecrypt</h2>
<type>Function</type>
<desc>
  Decrypt an encrypted (40 or 128 bits with certificate) PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_certfile blob</param-def>
  <param-desc>the certificate file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the password to the certificate file</param-desc>
 </param>
 </params>
<return>
  <return-def>blob</return-def>
  <return-desc>result PDF document</return-desc>
</return>
*/
function PublicKeyDecrypt(
  p_inputfile blob,
  p_certFile blob,
  p_password varchar2
  ) return blob;

/**
<h2>conv</h2>
<type>Function</type>
<desc>
  Util function for convert a measure to point (pt).
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_mes number</param-def>
  <param-desc>original measure</param-desc>
  <param-ul>
   <param-li>pt: point</param-li>
   <param-li>mm: millimeter</param-li>
   <param-li>cm: centimeter</param-li>
   <param-li>in: inch</param-li>
  </param-ul>
 </param>
 <param>
  <param-def>p_unit varchar2</param-def>
  <param-desc>original unit of measure</param-desc>
 </param>
</params>
<return>
 <return-def>number</return-def>
 <return-desc>measure in point</return-desc>
</return>
*/
function conv(
  p_mes number,
  p_unit varchar2   --pt,mm,cm,in
  ) return number;  --pt

/**
<h2>ExtractText</h2>
<type>Function</type>
<desc>
  Extract text content of any PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_encoding varchar2 default null</param-def>
  <param-desc>encoding of result text file (case-sensitive) see <a>http://java.sun.com/j2se/1.4.2/docs/guide/intl/encoding.doc.html</a>
  </param-desc>
 </param>
 <param>
  <param-def>p_startPage number default null</param-def>
  <param-desc>the start page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_endPage number default null</param-def>
  <param-desc>the end page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result TEXT document</return-desc>
</return>
*/
function ExtractText(
  p_inputfile blob,
  p_encoding varchar2 default null,
  p_startPage number default null,
  p_endPage number default null,
  p_password varchar2 default null
  ) return blob;

/**
<h2>Merge</h2>
<type>Function</type>
<desc>
Merge two PDF documents to a new file.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile1 blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_inputfile2 blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password1 varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_password2 varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function Merge(
  p_inputfile1 blob,
  p_inputfile2 blob,
  p_password1 varchar2 default null,
  p_password2 varchar2 default null
  ) return blob;

/**
<h2>MergeX</h2>
<type>Function</type>
<desc>
Merge PDF documents to a new file.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfiles t_merge_inputs</param-def>
  <param-desc>source PDF files</param-desc>
 </param>
 <param>
  <param-def>p_x number default 0</param-def>
  <param-desc>X coordinate (top left) for the numbering, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)</param-desc>
 </param>
 <param>
  <param-def>p_y number default 0</param-def>
  <param-desc>Y coordinate (top left) for the numbering, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)</param-desc>
 </param>
 <param>
  <param-def> p_font t_14font</param-def>
  <param-desc>Standard Base 14 Font</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc> font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color t_color default null</param-def>
  <param-desc>color of text
   see <a>http://www.forret.com/tools/color_palette.asp</a>
  </param-desc>
 </param>
 <param>
  <param-def>p_startNumber number default 1</param-def>
  <param-desc>Start number of the page numbering</param-desc>
 </param>
 <param>
  <param-def>p_beginNumber number default 1</param-def>
  <param-desc>Start page index from which you want to start the page numbering</param-desc>
 </param>
 <param>
  <param-def>p_nbAlias varchar2 default null</param-def>
  <param-desc>Page number alias, example 'nb'</param-desc>
 </param>
 <param>
  <param-def>p_cpAlias varchar2 default null</param-def>
  <param-desc>Current page number alias, example 'cp'</param-desc>
 </param>
 <param>
  <param-def>p_format varchar2 default null</param-def>
  <param-desc>Page numbering format, example 'cp / nb'</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MergeX(
  p_inputfiles t_merge_inputs,
  p_x number default 0, -- -1:center, -2:right
  p_y number default 0, -- -1:center, -2: bottom
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null,
  p_startNumber number default 1,
  p_beginNumber number default 1,
  p_nbAlias varchar2 default null,--LL20110920
  p_cpAlias varchar2 default null, --LL20110920
  p_format varchar2 default null  --LL20110920
  ) return blob;

/**
<h2>MergeX</h2>
<type>Function</type>
<desc>
Merge PDF documents to a new file. PDF files stored in plpdf_tk_merge_inputs table.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_tr_id number</param-def>
  <param-desc>Transaction ID of the source PDF files</param-desc>
 </param>
 <param>
  <param-def>p_x number default 0</param-def>
  <param-desc>X coordinate (top left) for the numbering, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)</param-desc>
 </param>
 <param>
  <param-def>p_y number default 0</param-def>
  <param-desc>Y coordinate (top left) for the numbering, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)</param-desc>
 </param>
 <param>
  <param-def> p_font t_14font</param-def>
  <param-desc>Standard Base 14 Font</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc> font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color t_color default null</param-def>
  <param-desc>color of text
   see <a>http://www.forret.com/tools/color_palette.asp</a>
  </param-desc>
 </param>
 <param>
  <param-def>p_startNumber number default 1</param-def>
  <param-desc>Start number of the page numbering</param-desc>
 </param>
 <param>
  <param-def>p_beginNumber number default 1</param-def>
  <param-desc>Start page index from which you want to start the page numbering</param-desc>
 </param>
 <param>
  <param-def>p_nbAlias varchar2 default null</param-def>
  <param-desc>Page number alias, example 'nb'</param-desc>
 </param>
 <param>
  <param-def>p_cpAlias varchar2 default null</param-def>
  <param-desc>Current page number alias, example 'cp'</param-desc>
 </param>
 <param>
  <param-def>p_format varchar2 default null</param-def>
  <param-desc>Page numbering format, example 'cp / nb'</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MergeX(
  p_tr_id number,
  p_x number default 0, -- -1:center, -2:right
  p_y number default 0, -- -1:center, -2: bottom
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null,
  p_startNumber number default 1,
  p_beginNumber number default 1,
  p_nbAlias varchar2 default null,
  p_cpAlias varchar2 default null,
  p_format varchar2 default null
  ) return blob;

/**
<h2>ReplaceUrl</h2>
<type>Function</type>
<desc>
  Replace an URL in a PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_oldURI varchar2</param-def>
  <param-desc>original URL</param-desc>
 </param>
 <param>
  <param-def>p_newURI varchar2</param-def>
  <param-desc>new URL</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function ReplaceUrl(
   p_inputfile blob,
   p_oldURI varchar2,
   p_newURI varchar2,
   p_password varchar2 default null
  ) return blob;

/**
<h2>JPGStamp</h2>
<type>Function</type>
<desc>
  Stamp content into a PDF document with a JPG image.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_imagefile blob</param-def>
  <param-desc>JPG image</param-desc>
 </param>
 <param>
  <param-def>p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1: center, -2: right
    (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def>p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1: center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def>p_width number default -1</param-def>
  <param-desc>Image width, if -1 then the image is displayed in its actual width
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def>p_height number default -1</param-def>
  <param-desc>Image height, if -1 then the image is displayed in its actual height
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function JPGStamp(
  p_inputfile blob,
  p_imagefile blob,
  p_x number,
  p_y number,
  p_width number default -1,
  p_height number default -1,
  p_password varchar2 default null,
  p_opacity number default 1
  ) return blob
;

/**
<h2>JPGWaterMark</h2>
<type>Function</type>
<desc>
  Watermark content into a PDF document with a JPG image.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_imagefile blob</param-def>
  <param-desc>JPG image</param-desc>
 </param>
 <param>
  <param-def> p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_width number default -1</param-def>
  <param-desc>Image width, if -1 then the image is displayed in its actual width
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_height number default -1</param-def>
  <param-desc>Image height, if -1 then the image is displayed in its actual height
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
 </params>
 <return>
  <return-def>blob</return-def>
  <return-desc>result PDF document</return-desc>
 </return>
*/
function JPGWaterMark(
  p_inputfile blob,
  p_imagefile blob,
  p_x number,
  p_y number,
  p_width number default -1,
  p_height number default -1,
  p_password varchar2 default null,
  p_opacity number default 1
  ) return blob;

/**
<h2>MetadataFromXML</h2>
<type>Function</type>
<desc>Set PDF metadata from an XML file.<br/>
  an example XML file:<br/>
  <i>
  &lt;?xml version="1.0" encoding="UTF-8"?&gt;<br/>
  &lt;pdf-metadata&gt;<br/>
  &lt;title&gt;PL/PDF Toolkit - User's Guide&lt;/title&gt;<br/>
  &lt;author&gt;PLPDF&lt;/author&gt;<br/>
  &lt;subject&gt;plpdf toolkit&lt;/subject&gt;<br/>
  &lt;creator&gt;PL/PDF v2.0.0&lt;/creator&gt;<br/>
  &lt;keywords&gt;Oracle PDF&lt;/keywords&gt;<br/>
  &lt;producer&gt;www.plpdf.com&lt;/producer&gt;<br/>
  &lt;createtime&gt;20080903183019&lt;/createtime&gt;<br/>
  &lt;modificationdate&gt;20080904114023&lt;/modificationdate&gt;<br/>
  &lt;/pdf-metadata&gt;<br/>
  </i>
  createtime and modificationdate format are YYYYMMDDHH24MISS
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_xmlfile blob</param-def>
  <param-desc>metadata XML file</param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MetadataFromXML(
  p_inputfile blob,
  p_xmlfile blob,
  p_password varchar2 default null
  ) return blob;

/**
<h2>MetadataFromPars</h2>
<type>Function</type>
<desc>
-
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_title varchar2 default null</param-def>
  <param-desc> The documents title.</param-desc>
 </param>
 <param>
  <param-def> p_author varchar2 default null</param-def>
  <param-desc>The name of the person who created the document.</param-desc>
 </param>
 <param>
  <param-def> p_subject varchar2 default null</param-def>
  <param-desc>The subject of the document.</param-desc>
 </param>
 <param>
  <param-def> p_creator varchar2 default null</param-def>
  <param-desc>If the document was converted to PDF from another format, the
    name of the application (for example, Adobe FrameMaker) that created the
    original document from which it was converted.
  </param-desc>
 </param>
 <param>
  <param-def> p_keywords varchar2 default null</param-def>
  <param-desc>Keywords associated with the document.</param-desc>
 </param>
 <param>
  <param-def> p_producer varchar2 default null</param-def>
  <param-desc>If the document was converted to PDF from another format, the
   name of the application (for example, Acrobat Distiller) that converted it to PDF.
  </param-desc>
 </param>
 <param>
  <param-def> p_createtime date default null</param-def>
  <param-desc>The date and time the document was created, in human-readable form.</param-desc>
 </param>
 <param>
  <param-def> p_modificationdate date default null</param-def>
  <param-desc>The date and time the document was most recently modified,
   in human-readable form.
  </param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function MetadataFromPars(
  p_inputfile blob,
  p_title varchar2 default null,
  p_author varchar2 default null,
  p_subject varchar2 default null,
  p_creator varchar2 default null,
  p_keywords varchar2 default null,
  p_producer varchar2 default null,
  p_createtime date default null,
  p_modificationdate date default null,
  p_password varchar2 default null
  ) return blob;

/**
<h2>MetadataToXML</h2>
<type>Function</type>
<desc>
  Extract PDF metadata into an XML file.<br/>
  An example XML file:<br/>
  <i>
  &lt;?xml version="1.0" encoding="UTF-8"?&gt;<br/>
  &lt;pdf-metadata&gt;<br/>
  &lt;title&gt;PL/PDF Toolkit - User's Guide&lt;/title&gt;<br/>
  &lt;author&gt;PLPDF&lt;/author&gt;<br/>
  &lt;subject&gt;plpdf toolkit&lt;/subject&gt;<br/>
  &lt;creator&gt;PL/PDF v2.0.0&lt;/creator&gt;<br/>
  &lt;keywords&gt;Oracle PDF&lt;/keywords&gt;<br/>
  &lt;producer&gt;www.plpdf.com&lt;/producer&gt;<br/>
  &lt;createtime&gt;20080903183019&lt;/createtime&gt;<br/>
  &lt;modificationdate&gt;20080904114023&lt;/modificationdate&gt;<br/>
  &lt;/pdf-metadata&gt;<br/>
  </i>
  createtime and modificationdate format are YYYYMMDDHH24MISS
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result XML document</return-desc>
</return>
*/
function MetadataToXML(
  p_inputfile blob,
  p_password varchar2 default null
  ) return blob;

/**
<h2>MetadataToRecord</h2>
<type>Function</type>
<desc>
 Extract PDF metadata into the t_metadata record.
</desc>
<version>v2.0.0</version>
<params>
<param>
<param-def>p_inputfile blob</param-def>
<param-desc>source PDF file</param-desc>
</param>
<param>
<param-def>p_password varchar2 default null</param-def>
<param-desc>the owner password of the PDF file (if encrypted).</param-desc>
</param>
</params>
<return>
<return-def>t_metadata</return-def>
<return-desc>PDF metadata</return-desc>
</return>
*/
function MetadataToRecord(
  p_inputfile blob,
  p_password varchar2 default null
  ) return t_metadata;

/**
<h2>TextStamp</h2>
<type>Function</type>
<desc>
  Stamp content into a PDF document with a text.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_message</param-def>
  <param-desc>stamp text (encoding: plpdf_toolkit_par.GetDefaultEncoding)</param-desc>
 </param>
 <param>
  <param-def> p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_font t_14font</param-def>
  <param-desc>Standard Base 14 Font</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc> font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color t_color default null</param-def>
  <param-desc>color of text
   see <a>http://www.forret.com/tools/color_palette.asp</a>
  </param-desc>
 </param>
 <param>
 <param-def> p_password varchar2 default null</param-def>
 <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_startPage number default null</param-def>
  <param-desc>the start page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_endPage number default null</param-def>
  <param-desc>the end page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_rotation number default 0</param-def>
  <param-desc>Text rotation angle</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function TextStamp(
  p_inputfile blob,
  p_message varchar2,
  p_x number,
  p_y number,
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null,
  p_password varchar2 default null,
  p_startPage number default null,
  p_endPage number default null,
  p_rotation number default 0,
  p_opacity number default 1
  ) return blob;

/**
<h2>TextStampTTF</h2>
<type>Function</type>
<desc>
  Stamp content into a PDF document with a text (TTF font type).
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_message</param-def>
  <param-desc>stamp text (encoding: plpdf_toolkit_par.GetDefaultEncoding)</param-desc>
 </param>
 <param>
  <param-def> p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_font blob</param-def>
  <param-desc>TTF (TrueType Font) file</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc>font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color t_color default null</param-def>
  <param-desc>color of text
   see <a>http://www.forret.com/tools/color_palette.asp</a>
  </param-desc>
 </param>
 <param>
 <param-def> p_password varchar2 default null</param-def>
 <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_startPage number default null</param-def>
  <param-desc>the start page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_endPage number default null</param-def>
  <param-desc>the end page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_rotation number default 0</param-def>
  <param-desc>Text rotation angle</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function TextStampTTF(
  p_inputfile blob,
  p_message varchar2,
  p_x number,
  p_y number,
  p_font blob,
  p_fontSize number,
  p_color t_color default null,
  p_password varchar2 default null,
  p_startPage number default null,
  p_endPage number default null,
  p_rotation number default 0,
  p_opacity number default 1
  ) return blob;

/**
<h2>TextWaterMark</h2>
<type>Function</type>
<desc>
  Watermark content into a PDF document with a text.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_message</param-def>
  <param-desc>watermark text (encoding: plpdf_toolkit_par.GetDefaultEncoding)</param-desc>
 </param>
 <param>
  <param-def> p_x number</param-def>
  <param-desc>X coordinate (top left) for the image, -1:center, -2: right
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_y number</param-def>
  <param-desc>Y coordinate (top left) for the image, -1:center, -2: bottom
   (unit in plpdf_toolkit_par.GetDefaultUOM function)
  </param-desc>
 </param>
 <param>
  <param-def> p_font t_14font</param-def>
  <param-desc>Standard Base 14 Font</param-desc>
 </param>
 <param>
  <param-def> p_fontSize number</param-def>
  <param-desc>font size in point</param-desc>
 </param>
 <param>
  <param-def> p_color plpdf_type.t_color default null</param-def>
  <param-desc>color of text see <a>http://www.forret.com/tools/color_palette.asp</a></param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_rotation number default 0</param-def>
  <param-desc>Text rotation angle</param-desc>
 </param>
 <param>
  <param-def>p_opacity number default 1</param-def>
  <param-desc>the constant opacity value to be used for the transparent imaging model, opacity vary from 0.0 (no contribution) to 1.0 (maximum contribution)</param-desc>
 </param>
 <param>
  <param-def>p_reencrypt boolean default false</param-def>
  <param-desc>Reencrypt document if encrypted.</param-desc>
 </param>
 </params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function TextWaterMark(
  p_inputfile blob,
  p_message varchar2,
  p_x number,
  p_y number,
  p_font t_14font,
  p_fontSize number,
  p_color t_color default null,
  p_password varchar2 default null,
  p_rotation number default 0,
  p_opacity number default 1,
  p_reencrypt boolean default false
  ) return blob;

/**
<h2>PDFWatermark</h2>
<type>Function</type>
<desc>
  Overlay on PDF document with another one PDF.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def> p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def> p_overlayinputfile blob</param-def>
  <param-desc>overlay PDF file</param-desc>
 </param>
 <param>
  <param-def> p_overlaypassword varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def> p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/

function PDFWatermark(
  p_inputfile blob,
  p_overlayinputfile blob,
  p_password varchar2 default null,
  p_overlaypassword varchar2 default null
  ) return blob;

/**
<name>ExportFDF</name>
<type>Function</type>
<desc>
  Export PDF Form data as an FDF file.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>FDF document</return-desc>
</return>
*/
function ExportFDF(
  p_inputfile blob,
  p_password varchar2 default null
  ) return blob;

/**
<name>ExportXFDF</name>
<type>Function</type>
<desc>
  Export PDF Form data as an XFDF file.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_exportnull boolean default true</param-def>
  <param-desc>export empty fields</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>XFDF document</return-desc>
</return>
*/
function ExportXFDF(
  p_inputfile blob,
  p_password varchar2 default null,
  p_exportnull boolean default true
  ) return blob;

/**
<name>ImportFDF</name>
<type>Function</type>
<desc>
  Import an FDF file into the PDF Form's fields.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_fdffile blob</param-def>
  <param-desc>FDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>FDF document</return-desc>
</return>
*/
function ImportFDF(
  p_inputfile blob,
  p_fdffile blob,
  p_password varchar2 default null
  ) return blob;

/**
<name>ImportXFDF</name>
<type>Function</type>
<desc>
  Import an XFDF file into the PDF Form's fields.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_xfdffile blob</param-def>
  <param-desc>XFDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_needapp boolean default true</param-def>
  <param-desc>Set NeedAppearances option in PDF source.
	When NeedAppearances is true then force compliant PDF readers to render the fields.
	If false then toolkit automatically generates the appearance streams for all form fields.
  </param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>XFDF document</return-desc>
</return>
*/
function ImportXFDF(
  p_inputfile blob,
  p_xfdffile blob,
  p_password varchar2 default null,
  p_needapp boolean default true
  ) return blob;

/**
<h2>ExtractPages</h2>
<type>Function</type>
<desc>
  Extract pages of any PDF document into a new PDF.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_startPage number default null</param-def>
  <param-desc>the start page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_endPage number default null</param-def>
  <param-desc>the end page to extract.</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function ExtractPages(
  p_inputfile blob,
  p_startPage number default null,
  p_endPage number default null,
  p_password varchar2 default null
  ) return blob;

/**
<h2>GetNumberOfPages</h2>
<type>Function</type>
<desc>
  Get number of pages of any PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>number</return-def>
 <return-desc>number of pages</return-desc>
</return>
*/
function GetNumberOfPages(
  p_inputfile blob,
  p_password varchar2 default null
  ) return number;

/**
<h2>JPGCompress</h2>
<type>Function</type>
<desc>
  Sets the compression quality to a value between 0  and 1 of the JPG images in a PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_compress number</param-def>
  <param-desc>compression quality to a value between 0  and 1</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function JPGCompress(
   p_inputfile blob,
   p_compress number,
   p_password varchar2 default null
  ) return blob;

/**
<h2>DigSign</h2>
<type>Function</type>
<desc>
  Digital sign a PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_keystore blob</param-def>
  <param-desc>keystore file</param-desc>
 </param>
 <param>
  <param-def>p_certAlias varchar2 default null</param-def>
  <param-desc>certificate alias in keystore file, null means first the first alias</param-desc>
 </param>
 <param>
  <param-def>p_keystorePassword varchar2 default null</param-def>
  <param-desc>password of keystore</param-desc>
 </param>
 <param>
  <param-def>p_privkeyPassword varchar2 default null</param-def>
  <param-desc>password of private key</param-desc>
 </param>
 <param>
   <param-def>p_Name varchar2 default null</param-def>
   <param-desc>The name of the person or authority signing the document.</param-desc>
  </param>
  <param>
   <param-def>p_Location varchar2 default null</param-def>
   <param-desc>The CPU host name or physical location of the signing.</param-desc>
  </param>
  <param>
   <param-def>p_Reason varchar2 default null</param-def>
   <param-desc>The reason for the signing, such as (I agree).</param-desc>
  </param>
  <param>
   <param-def>p_ContactInfo varchar2 default null</param-def>
   <param-desc>Information provided by the signer to allow a recipient to contact the signer to verify the signature; for example, a phone number.</param-desc>
  </param>
  <param>
   <param-def>p_page number default 0</param-def>
   <param-desc>page number of digital signature's postion </param-desc>
  </param>
  <param>
   <param-def>p_x number default 0</param-def>
   <param-desc>X coordinate for the top left corner of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_y number default 0</param-def>
   <param-desc>Y coordinate for the top left corner of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_w number default 0</param-def>
   <param-desc>The width of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_h number default 0</param-def>
   <param-desc>The height of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_access_perms</param-def>
   <param-desc>The access permissions granted for this document. Defined values are:</param-desc>
   <param-ul>
     <param-li>1: No changes to the document are permitted; any change to the document invalidates the signature.</param-li>
     <param-li>2: Permitted changes are filling in forms, instantiating page templates, and signing; other changes invalidate the signature.</param-li>
     <param-li>3: Permitted changes are those allowed by 2, as well as annotation creation, deletion, and modification; other changes invalidate the signature.</param-li>
    </param-ul>
  </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function DigSign(
   p_inputfile blob,
   p_keystore blob,
   p_certAlias varchar2 default null,
   p_keystorePassword varchar2 default null,
   p_privkeyPassword varchar2 default null,
   p_Name varchar2 default null,
   p_Location varchar2 default null,
   p_Reason varchar2 default null,
   p_ContactInfo varchar2 default null,
   p_page number default 0,
   p_x number default 0,
   p_y number default 0,
   p_width number default 0,
   p_height number default 0,
   p_accessPerms number default 1,
   p_password varchar2  default null
  ) return blob;

/**
<h2>DigSignEncrypt</h2>
<type>Function</type>
<desc>
  Digital sign and encrypt a PDF document.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_keystore blob</param-def>
  <param-desc>keystore file</param-desc>
 </param>
 <param>
  <param-def>p_certAlias varchar2 default null</param-def>
  <param-desc>certificate alias in keystore file, null means first the first alias</param-desc>
 </param>
 <param>
  <param-def>p_keystorePassword varchar2 default null</param-def>
  <param-desc>password of keystore</param-desc>
 </param>
 <param>
  <param-def>p_privkeyPassword varchar2 default null</param-def>
  <param-desc>password of private key</param-desc>
 </param>
 <param>
   <param-def>p_Name varchar2 default null</param-def>
   <param-desc>The name of the person or authority signing the document.</param-desc>
  </param>
  <param>
   <param-def>p_Location varchar2 default null</param-def>
   <param-desc>The CPU host name or physical location of the signing.</param-desc>
  </param>
  <param>
   <param-def>p_Reason varchar2 default null</param-def>
   <param-desc>The reason for the signing, such as (I agree).</param-desc>
  </param>
  <param>
   <param-def>p_ContactInfo varchar2 default null</param-def>
   <param-desc>Information provided by the signer to allow a recipient to contact the signer to verify the signature; for example, a phone number.</param-desc>
  </param>
  <param>
   <param-def>p_page number default 0</param-def>
   <param-desc>page number of digital signature's postion </param-desc>
  </param>
  <param>
   <param-def>p_x number default 0</param-def>
   <param-desc>X coordinate for the top left corner of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_y number default 0</param-def>
   <param-desc>Y coordinate for the top left corner of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_w number default 0</param-def>
   <param-desc>The width of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_h number default 0</param-def>
   <param-desc>The height of the rectangle</param-desc>
  </param>
  <param>
   <param-def>p_access_perms</param-def>
   <param-desc>The access permissions granted for this document. Defined values are:</param-desc>
   <param-ul>
     <param-li>1: No changes to the document are permitted; any change to the document invalidates the signature.</param-li>
     <param-li>2: Permitted changes are filling in forms, instantiating page templates, and signing; other changes invalidate the signature.</param-li>
     <param-li>3: Permitted changes are those allowed by 2, as well as annotation creation, deletion, and modification; other changes invalidate the signature.</param-li>
    </param-ul>
  </param>
 <param>
  <param-def>p_password varchar2 default null</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
 <param>
  <param-def>p_opassword varchar2</param-def>
  <param-desc>the owner password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_upassword varchar2 default null</param-def>
  <param-desc>the user password to the PDF file</param-desc>
 </param>
 <param>
  <param-def>p_canassemble boolean default false</param-def>
  <param-desc>The user is allowed to assemble the document
   (insert, rotate, or delete pages and create bookmarks or thumbnail images).
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractcontent boolean default false</param-def>
  <param-desc>The user is allowed to copy or otherwise
    extract text and graphics from the document.
  </param-desc>
 </param>
 <param>
  <param-def>p_canextractforaccessibility boolean default false</param-def>
  <param-desc>The user is allowed to extract text and graphics
   (in support of accessibility to disabled users or for other purposes).
  </param-desc>
 </param>
 <param>
  <param-def>p_canfillinform boolean default false</param-def>
  <param-desc>The user is allowed to fill in existing interactive form fields
   (including signature fields)
  </param-desc>
 </param>
 <param>
  <param-def>p_canmodify boolean default false</param-def>
  <param-desc>The user is allowed to modify the contents of the document</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyannotations boolean default false</param-def>
  <param-desc>Add or modify text annotations, fill in interactive form fields.</param-desc>
 </param>
 <param>
  <param-def>p_canprint boolean default false</param-def>
  <param-desc>Print the document to a representation from which a faithful digital copy
  of the PDF content could be generated.</param-desc>
 </param>
 <param>
  <param-def>p_canmodifyprintresolution boolean default false</param-def>
  <param-desc>The user is not allowed to print in highest quality.</param-desc>
 </param>
 <param>
  <param-def>p_algorithm varchar2 default 'RC4'</param-def>
  <param-desc>The encryption algorithm, possible values are RC4 and AES</param-desc>
 </param>
 <param>
  <param-def>p_keylength number default 40</param-def>
  <param-desc>The encryption key length in bit, possible values are 40 and 128</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function DigSignEncrypt(
   p_inputfile blob,
   p_keystore blob,
   p_certAlias varchar2 default null,
   p_keystorePassword varchar2 default null,
   p_privkeyPassword varchar2 default null,
   p_name varchar2 default null,
   p_location varchar2 default null,
   p_reason varchar2 default null,
   p_contactInfo varchar2 default null,
   p_page number default 0,
   p_x number default 0,
   p_y number default 0,
   p_width number default 0,
   p_height number default 0,
   p_accessPerms number default 1,
   p_password varchar2 default null,
   p_opassword varchar2,
   p_upassword varchar2 default null,
   p_canassemble boolean default false,
   p_canextractcontent boolean default false,
   p_canextractforaccessibility boolean default false,
   p_canfillinform boolean default false,
   p_canmodify boolean default false,
   p_canmodifyannotations boolean default false,
   p_canprint boolean default false,
   p_canmodifyprintresolution boolean default false, --v1.8.0
   p_algorithm varchar2 default 'RC4',
   p_keylength number default 40
  ) return blob;

/**
<h2>Rebuild</h2>
<type>Function</type>
<desc>
  Rebuild any PDF document into a new PDF.
</desc>
<version>v2.0.0</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function Rebuild(
  p_inputfile blob,
  p_password varchar2 default null
  ) return blob;

/**
<name>Get_Version</name>
<type>Function</type>
<desc>
  Get version number of the toolkit.
</desc>
<version>v2.0.0</version>
<return>
 <return-def>varchar2</return-def>
 <return-desc>version number</return-desc>
</return>
*/
function get_Version return varchar2;

/**
<name>Get_VersionDate</name>
<type>Function</type>
<desc>
  Get release date of the toolkit.
</desc>
<version>v2.0.0</version>
<return>
 <return-def>varchar2</return-def>
 <return-desc>release date</return-desc>
</return>
*/
function get_VersionDate return varchar2;


/**
<h2>setFieldsReadonly</h2>
<type>Function</type>
<desc>
  Set the PDF form fields to read-only.
</desc>
<version>v2.0.1</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>blob</return-def>
 <return-desc>result PDF document</return-desc>
</return>
*/
function setFieldsReadonly(
  p_inputfile blob,
  p_password varchar2 default null
  ) return blob;


/**
<h2>getPDFACompliant</h2>
<type>Function</type>
<desc>
  Get the PDF/A Compliant information.
</desc>
<version>v2.0.1</version>
<params>
 <param>
  <param-def>p_inputfile blob</param-def>
  <param-desc>source PDF file</param-desc>
 </param>
 <param>
  <param-def>p_password varchar2</param-def>
  <param-desc>the owner password of the PDF file (if encrypted).</param-desc>
 </param>
</params>
<return>
 <return-def>The Compliant info</return-def>
 <return-desc>Format is part + conf, example 1B</return-desc>
</return>
*/
function getPDFACompliant(
  p_inputfile blob,
  p_password varchar2 default null
  ) return varchar2;
  
-- end of package

-------------------------------------------------------
/**
 <newpage/>
 <h1>Version History</h1>
 <br/>
 */
-------------------------------------------------------

/**
 <h2>03-DEC-2012, v1.7.0</h2>
 <p>- JPGStamp: new parameter: p_opacity</p>
 <p>- JPGWaterMark: new parameter: p_opacity</p>
 <p>- TextStamp: new parameter: p_opacity</p>
 <p>- TextWaterMark: new parameter: p_opacity</p>
 <h2>01-FEB-2013, v1.8.0</h2>
 <p>- code optimalization</p>
 <h2>01-OKT-2013, v2.0.0</h2>
 <p>- code optimalization (Oracle 11g)</p>
 <p>- new function: TextStampTTF</p>
 <p>- Encrypt128: parameter rename: old name: p_canprintdegraded, new name: p_canmodifyprintresolution</p>
 <p>- AESEncrypt128: parameter rename: old name: p_canprintdegraded, new name: p_canmodifyprintresolution</p>
 <p>- PublicKeyEncrypt128: parameter rename: old name: p_canprintdegraded, new name: p_canmodifyprintresolution</p>
 <p>- JPGStamp: top-left origin coordinate system, p_y:=-2 is bottom Y coordinate</p>
 <p>- JPGWatermark: top-left origin coordinate system, p_y:=-2 is bottom Y coordinate</p>
 <p>- TextStamp: top-left origin coordinate system, p_y:=-2 is bottom Y coordinate</p>
 <p>- TextStampTTF: top-left origin coordinate system, p_y:=-2 is bottom Y coordinate</p>
 <p>- TextWatermark: top-left origin coordinate system, p_y:=-2 is bottom Y coordinate</p>
 <p>- DigSign: top-left origin coordinate system</p>
 <p>- DigSignEncrypt: top-left origin coordinate system</p>
 <h2>18-DEC-2013, v2.0.0</h2>
 <p>- new function: get_Version</p>
 <p>- new function: get_VersionDate</p>
 <p>- ImportXFDF: new parameter: p_needapp</p>
 <p>- TextWaterMark: new parameter: p_reencrypt</p>
*/

end;
/

CREATE OR REPLACE PACKAGE BODY plpdf_toolkit wrapped 
a000000
aa
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
b
e7fc 6d8c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/
